<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/svp?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'action_patienter' => 'Выполняются операции. Пожалуйста, подождите немного…',
	'actions_a_faire' => 'Выполнить операцию',
	'actions_demandees' => 'Необходимо выполнить операцию:',
	'actions_en_erreur' => 'Произошли ошибки',
	'actions_necessaires' => 'Будут выполнены следующие операции:',
	'actions_non_traitees' => 'Операция не выполнена',
	'actions_realises' => 'Операция выполнена',
	'afficher_les_plugins_incompatibles' => 'Показать несовместимые плагины',
	'alerte_compatibilite' => 'Принудительная совместимость',

	// B
	'bouton_activer' => 'Включить',
	'bouton_actualiser' => 'Обновить',
	'bouton_actualiser_tout' => 'Обновить репозитории',
	'bouton_appliquer' => 'Применить',
	'bouton_confirmer' => 'Подтвердить',
	'bouton_desactiver' => 'Отключить',
	'bouton_desinstaller' => 'Удалить',
	'bouton_installer' => 'Загрузить и включить',
	'bouton_modifier_depot' => 'Редактировать репозиторий',
	'bouton_supprimer' => 'Удалить',
	'bouton_up' => 'Обновить',
	'bulle_actualiser_depot' => 'Обновить пакеты в репозитории',
	'bulle_actualiser_tout_depot' => 'Обновить пакеты во всех репозиториях',
	'bulle_afficher_xml_plugin' => 'Содержимое XML файла плагина',
	'bulle_ajouter_spipzone' => 'Добавить репозиторий  SPIP-Zone',
	'bulle_aller_demonstration' => 'Перейти к странице демонстрации',
	'bulle_aller_depot' => 'Перейти на страницу репозитория',
	'bulle_aller_documentation' => 'Перейти на страницу с документацией',
	'bulle_aller_plugin' => 'Перейти на страницу пакета',
	'bulle_supprimer_depot' => 'Удалить репозиторий и его пакеты',
	'bulle_telecharger_archive' => 'Скачать архивный файл',
	'bulle_telecharger_fichier_depot' => 'Добавить XML файл репозитория',
	'bulle_telecharger_librairie' => 'Скачать библиотеку',

	// C
	'cacher_les_plugins_incompatibles' => 'Скрыть несовместимые плагины',
	'categorie_aucune' => 'Тематика не задана',
	'categorie_auteur' => 'Авторы, авторизация, управление  правами доступа',
	'categorie_communication' => 'Интерактивность, коммуникации',
	'categorie_date' => 'Расписания, календари, дата и время',
	'categorie_divers' => 'Внешние сервисы, новые объекты',
	'categorie_edition' => 'Работа с текстом, печать',
	'categorie_maintenance' => 'Настройки и обслуживание',
	'categorie_multimedia' => 'Файлы мультимедиа, галереи, картинки',
	'categorie_navigation' => 'Навигация, поиск',
	'categorie_outil' => 'Средства разработки',
	'categorie_performance' => 'Оптимизация, быстродействие, безопасность',
	'categorie_squelette' => 'Шаблоны',
	'categorie_statistique' => 'SEO и статистика',
	'categorie_theme' => 'Темы оформления',
	'config_activer_log_verbeux' => 'Включить подробное логирование?',
	'config_activer_log_verbeux_explication' => 'Эта опция позволяет вести подробное логирование действий…',
	'config_activer_pas_a_pas' => 'Включить пошаговый режим?',
	'config_activer_pas_a_pas_explication' => 'Данная опция позволяет выполнять операции с плагинами не в пакетном режиме (когда сразу выполняется несколько операций), а пошагово, подтверждая каждую операцию.',
	'config_activer_runtime' => 'Включить режим совместимости?',
	'config_activer_runtime_explication' => 'Если режим совместимости включен, то будут показываться только плагины совместимые с текущей версией SPIP. Если режим совместимости выключен, то будут показываться все плагины вне зависимости от текущей версии.',
	'config_autoriser_activer_paquets_obsoletes' => 'Разрешить включать устаревшие плагины?',
	'config_autoriser_activer_paquets_obsoletes_explication' => 'Устаревшие плагины - это плагины, установленные на вашем сайте, которые старше других плагинов. Определяется по статусу плагина (тестируется, стабильный и т.д.), а так же по номеру текущей версии. Включите эту настройку, если вы хотите иметь возможность использовать устаревшие плагины.',
	'config_depot_editable' => 'Разрешить редактирование репозитория?',
	'config_depot_editable_explication' => 'Возможность редактировать информацию о репозитории. Такой потребности не должно у вас возникнуть, поэтому оставьте эту опцию выключенной.',
	'confirmer_desinstaller' => 'Внимание: деинсталляция плагина <b>удаляет</b> его базу данных и является необратимой. <br /> Если вы не уверены, просто отключите плагин.',
	'confirmer_telecharger_dans' => 'Эта операция перезапишет содержимое папки.
Плагин будет загружен в существующую папку «@dir@».
Старые файлы будут сохранены в папке «@dir_backup@».
Вам необходимо подтвердить выполнение этой операции.
		',

	// E
	'erreur_actions_non_traitees' => 'Некоторые операции не были выполнены. Возможно, были ошибки в процессе выполнения. Выполнение операции инициировал @auteur@  @date@.',
	'erreur_auth_plugins_ajouter_lib' => 'Недостаточно прав для того, чтобы установить библиотеку.',
	'erreur_dir_dib_ecriture' => 'Отсутствуют права на запись папки @dir@. Невозможно загрузить библиотеку!',
	'erreur_dir_dib_indefini' => 'Не задано значение _DIR_LIB. Невозможно загрузить библиотеку!',
	'erreur_dir_plugins_auto' => 'Папка «plugins/auto» позволяющая добавлять плагины из административной части сайта не создана или не хватает прав для записи в нее. Если вы хотите иметь такую возможность, то <strong>вам необходимо ее создать или установить права доступа 777 ( если такая папка существует)</strong>.',
	'erreur_dir_plugins_auto_ecriture' => 'Отсутствуют права на запись в папке @dir@. Невозможно загрузить пакет!',
	'erreur_dir_plugins_auto_indefini' => 'Не указана папка _DIR_PLUGIN_AUTO. Невозможно загрузить плагин!',
	'erreur_dir_plugins_auto_titre' => 'недоступна папка «plugins/auto»!',
	'erreur_teleporter_chargement_source_impossible' => 'Невозможно загрузить источник @source@',
	'erreur_teleporter_destination_erreur' => 'Папка @dir@ недоступна для  загрузчика файлов',
	'erreur_teleporter_echec_deballage_archive' => 'Не получается разархивировать файл @fichier@',
	'erreur_teleporter_format_archive_non_supporte' => 'Формат файлов @extension@ не поддерживается загрузчиком файлов',
	'erreur_teleporter_methode_inconue' => 'Неизвестный метод @methode@ для загрузчика файлов',
	'erreur_teleporter_type_fichier_inconnu' => 'Неизвестный тип файла для источника @source@',
	'erreurs_xml' => 'Невозможно прочитать некоторые XML описания',
	'explication_destination' => 'Если вы не заполните, то путь будет задан по имени архивного файла.',

	// F
	'fieldset_debug' => 'Отладка',
	'fieldset_edition' => 'Редактирование',
	'fieldset_fonctionnement' => 'Функционирование',

	// I
	'info_1_depot' => '1 репозиторий',
	'info_1_paquet' => '1 пакет',
	'info_1_plugin' => '1 плагин',
	'info_admin_plugin_actif_non_verrou_non' => 'Список отключенных плагинов.',
	'info_admin_plugin_actif_non_verrou_tous' => 'Список отключенных плагинов.',
	'info_admin_plugin_actif_oui_verrou_non' => 'Список всех включенных плагинов (кроме системных).',
	'info_admin_plugin_actif_oui_verrou_tous' => 'Список всех включенных плагинов, установленных и системных.',
	'info_admin_plugin_verrou_non' => 'Список всех плагинов, кроме системных. Включенные и отключенные.',
	'info_admin_plugin_verrou_tous' => 'Список всех плагинов на сайте.',
	'info_admin_plugin_verrouille' => 'На этой странице вы видите список всех включенных и системных плагинов (установленных в папке <code>@dir_plugins_dist@</code>).
Если вы хотите отключить плагин - свяжитесь с разработчиками сайта или проконсультируйтесь в  <a href="http://programmer.spip.org/repertoire_plugins_dist">документации</a>.',
	'info_adresse_spipzone' => 'Плагины SPIP-Zone',
	'info_ajouter_depot' => 'Добавив репозиторий на сайт вы получаете возможность получить информацию о всех плагинах, которые находятся в репозитории. <br /> Название и описание плагинов содержится в  XML файле репозитория.',
	'info_aucun_depot' => 'Нет репозитория',
	'info_aucun_depot_ajoute' => 'Нет добавленных репозиториев !<br /> Используйте эту форму, что бы добавить репозиторий «Плагины SPIP-Zone», ссылка на который установлена по умолчанию.',
	'info_aucun_paquet' => 'нет пакетов',
	'info_aucun_plugin' => 'Нет плагинов',
	'info_boite_charger_plugin' => '<strong>Эта страница доступна только для вебмастеров сайта.</strong><p>На ней расположена система поиска по плагинам, а также реализована возможность добавлять их на сайт.</p>',
	'info_boite_depot_gerer' => '<strong>Страница доступна только для вебмастера сайта.</strong><p>Тут вы можете добавлять и изменять репозитории плагинов.</p>',
	'info_charger_plugin' => 'Для того, что бы добавить плагин, найдите при помощи системы поиска. Поиск выполняется только среди плагинов, совместимых в версией SPIP, используемой на сайте.',
	'info_compatibilite_dependance' => 'Для @compatibilite@ :',
	'info_contributions_hebergees' => '@total_autres@ прочих  разработок',
	'info_critere_phrase' => 'Задайте слово  для поиска в названии, описании, слогане, префиксе или разработчиков плагинов.',
	'info_depots_disponibles' => '@total_depots@ репозиториев',
	'info_fichier_depot' => 'Укажите ссылку на XML файл репозитория.<br /> Чтобы добавить репозиторий  « Плагины SPIP-Zone » просто нажмите на ссылку: ',
	'info_nb_depots' => '@nb@ репозиториев',
	'info_nb_paquets' => '@nb@ пакетов',
	'info_nb_plugins' => '@nb@ плагинов',
	'info_paquets_disponibles' => 'доступно @total_paquets@ пакетов',
	'info_plugin_attente_dependance' => 'не хватает зависимых пакетов',
	'info_plugin_incompatible' => 'несовместимая версия',
	'info_plugin_installe' => 'уже установлено',
	'info_plugin_obsolete' => 'устаревшая версия',
	'info_plugins_disponibles' => 'доступно @total_plugins@ плагинов',
	'info_plugins_heberges' => 'Размещено @total_plugins@ плагинов',
	'info_tri_nom' => 'в алфавитном порядке',
	'info_tri_score' => 'сортировать по релевантности',
	'info_type_depot_git' => 'Репозиторий под управлением GIT',
	'info_type_depot_manuel' => 'Простой репозиторий ( без системы управления версиями)',
	'info_type_depot_svn' => 'Репозиторий на системе SVN',
	'info_verrouille' => 'Системный плагин. Его нельзя отключить или удалить.',
	'installation_en_cours' => 'Выполняются запрошенные операции',

	// L
	'label_1_autre_contribution' => 'другие разработки',
	'label_actualise_le' => 'Обновление',
	'label_archive' => 'Ссылка на архивный файл плагина ',
	'label_branches_spip' => 'Совместимый',
	'label_categorie' => 'Тематика',
	'label_compatibilite_spip' => 'Совместимость',
	'label_critere_categorie' => 'Тематика',
	'label_critere_depot' => 'Репозиторий',
	'label_critere_doublon' => 'Совместимость',
	'label_critere_etat' => 'Статус',
	'label_critere_phrase' => 'Найти плагин',
	'label_destination' => 'Путь относительно папки « auto » для загрузки плагина',
	'label_modifie_le' => 'Изменялось',
	'label_n_autres_contributions' => 'другие разработки',
	'label_prefixe' => 'Префикс',
	'label_selectionner_plugin' => 'Выбрать плагин',
	'label_tags' => 'Теги',
	'label_type_depot' => 'Тип репозитория :',
	'label_type_depot_git' => 'GIT репозиторий',
	'label_type_depot_manuel' => 'Простой репозиторий',
	'label_type_depot_svn' => 'SVN репозиторий',
	'label_url_archives' => 'URL архивного файла',
	'label_url_brouteur' => 'URL корневой папки с исходным кодом',
	'label_url_serveur' => 'URL сервера',
	'label_version' => 'Версия',
	'label_xml_depot' => 'XML файл репозитория',
	'label_xml_plugin' => 'XML',
	'legende_installer_plugins' => 'Установить плагин',
	'legende_rechercher_plugins' => 'Поиск плагинов',
	'lien_demo' => 'Демонстрация',
	'lien_documentation' => 'Документация',

	// M
	'message_action_finale_get_fail' => 'Не удалось загрузить плагин «@plugin@» (версия: @version@) ',
	'message_action_finale_get_ok' => 'Плагин «@plugin@» (версия: @version@) успешно загружен',
	'message_action_finale_getlib_fail' => 'Не удалось установить библиотеку «@plugin@»',
	'message_action_finale_getlib_ok' => 'Библиотека «@plugin@» успешно установлена',
	'message_action_finale_geton_fail' => 'Не удалось загрузить и установить плагин «@plugin@» (версия: @version@) ',
	'message_action_finale_geton_ok' => 'Плагин «@plugin@» (версия: @version@) успешно загружен и установлен',
	'message_action_finale_install_fail' => 'Не удалось установить плагин «@plugin@» (версия : @version@) ',
	'message_action_finale_install_ok' => 'Плагин «@plugin@» (версия : @version@) успешно установлен',
	'message_action_finale_kill_fail' => 'Не удалось удалить файлы плагина « @plugin@ » (версия : @version@)',
	'message_action_finale_kill_ok' => 'Файлы плагина «@plugin@» (версия : @version@) успешно удалены',
	'message_action_finale_off_fail' => 'Не удалось отключить плагин «@plugin@» (версия: @version@) ',
	'message_action_finale_off_ok' => 'Плагин «@plugin@» (version: @version@) успешно отключён',
	'message_action_finale_on_fail' => 'Не удалось включить плагин «@plugin@» (версия: @version@) ',
	'message_action_finale_on_ok' => 'Плагин «@plugin@» (версия: @version@) включён ',
	'message_action_finale_stop_fail' => 'Не удалось удалить плагин «@plugin@» (версия: @version@)',
	'message_action_finale_stop_ok' => 'Плагин «@plugin@» (версия: @version@) успешно удалён',
	'message_action_finale_up_fail' => 'Не удалось обновить плагин «@plugin@» с версии @version@ до @version_maj@',
	'message_action_finale_up_ok' => 'Обновление плагина «@plugin@» (с версии @version@ до  @version_maj@) прошло успешно',
	'message_action_finale_upon_fail' => 'Не удалось обновить и включить плагин «@plugin@» (с  @version@ до @version_maj@) ',
	'message_action_finale_upon_ok' => 'Плагин «@plugin@» успешно обновлён с версии  @version@ до @version_maj@ и включён',
	'message_action_get' => 'Загрузить плагин «@plugin@» (версия: @version@)',
	'message_action_getlib' => 'Скачать библиотеку « <a href="@version@" class="spip_out">@plugin@</a> »',
	'message_action_geton' => 'Скачать и включить плагин «@plugin@» (версия: @version@)',
	'message_action_install' => 'Будет установлен плагин «@plugin@» (версия : @version@) va être installé',
	'message_action_kill' => 'Удалить файлы из плагина «@plugin@» (версия: @version@)',
	'message_action_off' => 'Отключить плагин «@plugin@» (версия: @version@)',
	'message_action_on' => 'Включить плагин «@plugin@» (версия: @version@)',
	'message_action_stop' => 'Удалить плагин «@plugin@» (версия: @version@)',
	'message_action_up' => 'Обновить плагин «@plugin@» (с @version@ до @version_maj@)',
	'message_action_upon' => 'Обновление и активация плагина «@plugin@» (версия: @version@)',
	'message_dependance_plugin' => 'Для  @plugin@ необходим @dependance@.',
	'message_dependance_plugin_version' => 'Для установки @plugin@ необходим @dependance@ @version@',
	'message_erreur_aucun_plugin_selectionne' => 'Ни один плагин не выбран.',
	'message_erreur_ecriture_lib' => 'Для установки плагина @plugin@ необходима библиотека <a href="@lib_url@">@lib@</a>. Библиотеки должны находится в папке <var>lib/</var> в корне сайта. Но либо этой папки не существует, либо не хватает прав на запись. Необходимо или создать папку, или установить права на запись (обычно 777).',
	'message_erreur_maj_inconnu' => 'Невозможно обновить неизвестный плагин (@id@).',
	'message_erreur_plugin_introuvable' => 'Не получается найти плагин @plugin@ для @action@.',
	'message_erreur_plugin_non_actif' => 'Нельзя отключить отключенный плагин.',
	'message_incompatibilite_spip' => '@plugin@  не совместим с текущей версией вашей CMS SPIP.',
	'message_nok_aucun_depot_disponible' => 'Нет доступных плагинов! Добавьте хотя бы один репозиторий на странице управления репозиториями.',
	'message_nok_aucun_paquet_ajoute' => 'В репозитории «@url@» нет новых пакетов по сравнению с плагинами в базе сайта. Репозиторий не был добавлен.',
	'message_nok_aucun_plugin_selectionne' => 'Не выбран ни один плагин. Выберите плагин, который вы хотите установить.',
	'message_nok_champ_obligatoire' => 'Поле, обязательное для заполнения',
	'message_nok_depot_deja_ajoute' => 'URL «@url@» соответствует уже добавленному репозиторию',
	'message_nok_maj_introuvable' => 'Не удалось найти новую версию плагина @plugin@ .',
	'message_nok_plugin_inexistant' => 'Запрошенный плагин не существует (@plugin@).',
	'message_nok_sql_insert_depot' => 'Произошла SQL ошибка при добавления репозитория @objet@',
	'message_nok_url_archive' => 'URL-адрес в архиве недействителен',
	'message_nok_url_depot_incorrecte' => 'Адрес «@url@» задан неправильно',
	'message_nok_xml_non_conforme' => 'Не подходит описание XML файла «@fichier@»',
	'message_nok_xml_non_recupere' => 'Не возможно восстановить XML файл «@fichier@» ',
	'message_ok_aucun_plugin_trouve' => 'Не найдены плагины по заданным критериям поиска.',
	'message_ok_depot_ajoute' => 'Репозиторий «@url@» успешно добавлен.',
	'message_ok_plugins_trouves' => 'Найдено @nb_plugins@ плагин(ов) по запросу (@tri@). Вы можете выбрать, какие плагины вы хотите скачать и установить.',
	'message_telechargement_archive_effectue' => 'Файл успешно разархивирован в папке @dir@.',

	// N
	'nettoyer_actions' => 'Очистить список операций! Вы можете удалить операции, намеченные к выполнению.',

	// O
	'onglet_depots' => 'Репозитории',
	'option_categorie_toute' => 'Все разделы',
	'option_depot_tout' => 'Все репозитории',
	'option_doublon_non' => 'Последняя версия',
	'option_doublon_oui' => 'Все совместимые версии',
	'option_etat_tout' => 'Все статусы',

	// P
	'placeholder_phrase' => 'префикс, название, слоган, описание или автор',
	'plugin_info_actif' => 'Плагин включен',
	'plugin_info_up' => 'Доступна новая версия плагина(версия @version@)',
	'plugin_info_verrouille' => 'Системный плагин',
	'plugins_inactifs_liste' => 'Выключенные',
	'plugins_non_verrouilles_liste' => 'Не обязательные',
	'plugins_verrouilles_liste' => 'Обязательные',

	// R
	'resume_table_depots' => 'Список добавленных репозиториев',
	'resume_table_paquets' => 'Список пакетов',
	'resume_table_plugins' => 'Плагины в разделе @categorie@',

	// T
	'telecharger_archive_plugin_explication' => 'Вы можете ввести прямую ссылку на файл с архивом плагина и он будет сохранен и установлен в папку «plugins/auto».',
	'titre_depot' => 'Репозиторий',
	'titre_depots' => 'Репозитории',
	'titre_form_ajouter_depot' => 'Добавить репозиторий',
	'titre_form_charger_plugin' => 'Найти и установить плагин',
	'titre_form_charger_plugin_archive' => 'Скачать архивный файл с плагином',
	'titre_form_configurer_svp' => 'Настроить сервер с плагинами',
	'titre_liste_autres_contributions' => 'Шаблоны, библиотеки, наборы иконок...',
	'titre_liste_autres_depots' => 'Другие репозитории',
	'titre_liste_depots' => 'Список доступных репозиториев',
	'titre_liste_paquets_plugin' => 'Список пакетов в плагине',
	'titre_liste_plugins' => 'Список плагинов',
	'titre_logo_depot' => 'Логотип репозитория',
	'titre_logo_plugin' => 'Логотип плагина',
	'titre_nouveau_depot' => 'Новый репозиторий',
	'titre_page_configurer' => 'Сервер плагинов',
	'titre_paquet' => 'Пакет',
	'titre_paquets' => 'Пакеты',
	'titre_plugin' => 'Плагин',
	'titre_plugins' => 'Плагины',
	'tout_cocher' => 'Выбрать все',
	'tout_cocher_up' => 'Проверить обновления',
	'tout_decocher' => 'Убрать выделение'
);

?>
